==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/base/http/httperror.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2017  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include "base/exceptions.h"

class HTTPError : public RuntimeError
{
public:
    HTTPError(int statusCode, const QString &statusText, const QString &message = "");

    int statusCode() const;
    QString statusText() const;

private:
    const int m_statusCode;
    const QString m_statusText;
};

class BadRequestHTTPError : public HTTPError
{
public:
    explicit BadRequestHTTPError(const QString &message = "");
};

class ForbiddenHTTPError : public HTTPError
{
public:
    explicit ForbiddenHTTPError(const QString &message = "");
};

class NotFoundHTTPError : public HTTPError
{
public:
    explicit NotFoundHTTPError(const QString &message = "");
};

class ConflictHTTPError : public HTTPError
{
public:
    explicit ConflictHTTPError(const QString &message = "");
};

class UnsupportedMediaTypeHTTPError : public HTTPError
{
public:
    explicit UnsupportedMediaTypeHTTPError(const QString &message = "");
};

class UnauthorizedHTTPError : public HTTPError
{
public:
    explicit UnauthorizedHTTPError(const QString &message = "");
};

class InternalServerErrorHTTPError : public HTTPError
{
public:
    explicit InternalServerErrorHTTPError(const QString &message = "");
};

==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/base/http/httperror.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2017  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include "base/exceptions.h"

class HTTPError : public RuntimeError
{
public:
    HTTPError(int statusCode, const QString &statusText, const QString &message = {});

    int statusCode() const;
    QString statusText() const;

private:
    const int m_statusCode;
    const QString m_statusText;
};

class BadRequestHTTPError : public HTTPError
{
public:
    explicit BadRequestHTTPError(const QString &message = {});
};

class UnauthorizedHTTPError : public HTTPError
{
public:
    explicit UnauthorizedHTTPError(const QString &message = {});
};

class ForbiddenHTTPError : public HTTPError
{
public:
    explicit ForbiddenHTTPError(const QString &message = {});
};

class NotFoundHTTPError : public HTTPError
{
public:
    explicit NotFoundHTTPError(const QString &message = {});
};

class MethodNotAllowedHTTPError : public HTTPError
{
public:
    explicit MethodNotAllowedHTTPError(const QString &message = {});
};

class ConflictHTTPError : public HTTPError
{
public:
    explicit ConflictHTTPError(const QString &message = {});
};

class UnsupportedMediaTypeHTTPError : public HTTPError
{
public:
    explicit UnsupportedMediaTypeHTTPError(const QString &message = {});
};

class InternalServerErrorHTTPError : public HTTPError
{
public:
    explicit InternalServerErrorHTTPError(const QString &message = {});
};
